@@ -48,8 +48,8 @@ GtkWidget * gnomechess_board_new()
   hbox = gtk_hbox_new(FALSE, FALSE);
   board.messages = zvt_term_new_with_size(80, 10);
   zvt_term_set_blink(ZVT_TERM(board.messages), FALSE);
-  scrollbar = gtk_vscrollbar_new (ZVT_TERM(board.messages)->adjustment);
-  gtk_vscrollbar_new (GTK_ADJUSTMENT(ZVT_TERM(board.messages)->adjustment));
+  zvt_term_set_scrollback(ZVT_TERM(board.messages), 100);
+  scrollbar = gtk_vscrollbar_new (GTK_ADJUSTMENT(ZVT_TERM(board.messages)->adjustment));
   GTK_WIDGET_UNSET_FLAGS(scrollbar, GTK_CAN_FOCUS);
   gtk_container_add(GTK_CONTAINER(hbox), board.messages);
   gtk_container_add(GTK_CONTAINER(hbox), scrollbar);
@@ -177,7 +177,7 @@ static int gnomechess_board_press_cb(GnomeCanvasItem *item, GdkEvent *event, gpo
 
 	if (to) {
 		int p = currPositionPtr->square[from];
-		gnomechess_position_make_move(currPositionPtr,from,to);
+		gnomechess_position_move(currPositionPtr,from,to);
 		if (!(board.mode == HUMANS))
 			engine_write_move(from,to);
 		gnomechess_movelist_add (board.movelist,p,from,to);
