@@ -22,7 +22,6 @@
 #include <stdarg.h>
 #include <signal.h>
 
-#include "portab.h"
 #include "pro.h"
 #include "child.h"
 
@@ -63,25 +62,21 @@ else   /* Child */
     close(pipe1[0]);
     close(pipe2[1]);
 
-    if (execvp(cmd,arg) <0)
-      perror("execvp");
-    return 0;
+    if (execvp(cmd,arg) < 0)
+      perror(cmd);
+    _exit(1);
   }
 
-// NOT REACHED
+  /* Should NEVER be reached */
   abort(); 
   return 0;
 }
 
-// Kill Child
-int stop_child(pid_t childpid)
-{
-
- if ( kill(childpid,SIGTERM) )
-   { 
-     if (debug)
-       fprintf(stderr,"kill failed\n");
-     return 1;
-   }
- return 0;
+/* Kill Child */
+int stop_child(pid_t childpid) {
+	if (childpid && kill(childpid,SIGTERM) ) { 
+		debug_print(DEBUG_NONE,"Failed to kill child!\n");
+		return 1;
+	}
+	return 0;
 }
