@@ -53,7 +53,6 @@ struct engine * engine_new(char *cmd, char **arg)
   e->menudata->menu_cwhite_cb = NULL;
   e->menudata->menu_cblack_cb = NULL;
   e->menudata->menu_twop_cb = NULL;
-  e->menudata->menu_twoc_cb = NULL;
   e->menudata->menu_analyze_cb = NULL;
 
   e->data = NULL;
@@ -79,7 +78,7 @@ void engine_write(struct engine *e, char *format,...)
   va_end(ap);
 }
 
-static void position_to_engine(struct engine *e)
+void position_to_engine(struct engine *e)
 {
   int i;
   char s[10];
@@ -105,7 +104,7 @@ static void position_to_engine(struct engine *e)
       *p++   = i - i / 10 * 10 + 96;   /*  a - h       */
       *p++   = i / 10 + 47 ;              /*  1 - 8       */
       *p=0;
-      printf("%s\n",s);  
+      debug_print(DEBUG_VERBOSE,"Set position: %s\n",s);  
       engine_write(e,"%s\n",s);  
     }
 
@@ -128,7 +127,7 @@ static void position_to_engine(struct engine *e)
       *p++   = i - i / 10 * 10 + 96;   /*  a - h       */
       *p++   = i / 10 + 47 ;              /*  1 - 8       */
       *p=0;
-      printf("%s\n",s);  
+      debug_print(DEBUG_VERBOSE,"Set position: %s\n",s);  
       engine_write(e,"%s\n",s);  
     }
 
@@ -138,11 +137,24 @@ static void position_to_engine(struct engine *e)
 void engine_write_move(int from, int to) {
   char s[100];
   char *str = NULL;
+  int curr;
 
   if (first_chess_programm == NULL) return;
 
-  if (gnomechess_movelist_currply(board.movelist) != gnomechess_movelist_maxply(board.movelist))
+  curr = gnomechess_movelist_currply(board.movelist);
+  if ( curr < gnomechess_movelist_maxply(board.movelist)) {
        position_to_engine(first_chess_programm);
+	   gnomechess_movelist_clear_from(board.movelist, curr);
+	   if ((currPositionPtr->tomove == WHITE && board.mode == COMPUTER_WHITE)) {
+			engine_write(first_chess_programm,"white\n");
+			engine_write(first_chess_programm,"go\n");
+		} 
+	   if ((currPositionPtr->tomove == BLACK && board.mode == COMPUTER_BLACK)) {
+			engine_write(first_chess_programm,"black\n");
+			engine_write(first_chess_programm,"go\n");
+		} 
+	   return;
+  }
 
   if (first_chess_programm->notation) {
 	move_to_ascii(s,from,to);
