@@ -25,6 +25,8 @@
 #include <string.h>
 #include <unistd.h>
 #include <config.h>
+
+#include "debug.h"
 #include "menu.h"
 #include "prefs.h"
 #include "timer.h"
@@ -33,5 +35,6 @@
 #include "engine.h"
 #include "engine_local.h"
 #include "engine_ics.h"
+#include "engine_null.h"
 
 #endif
