@@ -18,9 +18,9 @@
 
 #define AB_ZUGL		512	/*  Laenge der Zugliste pro Zug		*/
 #define AB_ZUG_S	256	/*  Beginn der Schlagzuege in Zugliste	*/
-#define WMOVE		1	/*  White to Move			*/
-#define BMOVE		129	/*  Black to move			*/
-#define NMOVE		0	/*  None to move			*/
+#define NONE		0	/*  None to move			*/
+#define WHITE		1	/*  White to Move			*/
+#define BLACK		129	/*  Black to move			*/
 #define	SAN		0	/*  Standard algebraic notation		*/
 #define	COORD		1	/*  Coordinate notation			*/
 
