@@ -106,9 +106,6 @@ static GnomeUIInfo options_mode_items[] =
   {GNOME_APP_UI_ITEM,N_("Two _Players"),NULL,menu_two_players_cb,NULL,
   NULL, GNOME_APP_PIXMAP_NONE,NULL,0,0,NULL},
 
-  {GNOME_APP_UI_ITEM,N_("Two _Computers"),NULL,menu_two_machines_cb,NULL,
-  NULL, GNOME_APP_PIXMAP_NONE,NULL,0,0,NULL},
-
   {GNOME_APP_UI_ITEM,N_("_Analyse Mode"),NULL,menu_analyse_mode_cb,NULL,
   NULL, GNOME_APP_PIXMAP_NONE,NULL,0,0,NULL},
 
@@ -225,8 +222,7 @@ void create_menus()
   menus[MENU_CWHITE] = &options_mode_items[0];
   menus[MENU_CBLACK] = &options_mode_items[1];
   menus[MENU_TWOP] = &options_mode_items[2];
-  menus[MENU_TWOC] = &options_mode_items[3];
-  menus[MENU_ANALYZE] = &options_mode_items[4];
+  menus[MENU_ANALYZE] = &options_mode_items[3];
   menus[MENU_LEVEL] = &options_menu[2];
 
 }
@@ -242,7 +238,7 @@ void uncheck_menu(gint item) {
 void uncheck_all_menus() {
 	int i;
 
-	for (i=14;i<19;i++)
+	for (i=14;i<18;i++)
 		uncheck_menu(i);
 }
 
@@ -349,10 +345,6 @@ void menu_two_players_cb (GtkWidget *widget, void *data) {
   board.mode = HUMANS;
 }
 
-void menu_two_machines_cb (GtkWidget *widget, void *data) {
-  board.mode = AUTOPLAY;
-}
-
 void menu_analyse_mode_cb (GtkWidget *widget, void *data) {
   board.mode = ANALYSE;
   engine_write(first_chess_programm,"analyze\n");
