@@ -1,6 +1,24 @@
+/* 
+ * Copyright (C) 1999 JP Rosevear
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
+ */
+
 #include <gnome.h>
 
-#define MENU_SIZE		20
+#define MENU_SIZE		19
 
 #define MENU_NEW		0
 #define MENU_LOAD		1
@@ -19,9 +37,8 @@
 #define MENU_CWHITE		14
 #define MENU_CBLACK		15
 #define MENU_TWOP		16
-#define MENU_TWOC		17
-#define MENU_ANALYZE		18
-#define MENU_LEVEL		19
+#define MENU_ANALYZE	17
+#define MENU_LEVEL		18
 
 void create_menus(void);
 void check_menu(gint item);
@@ -51,7 +68,6 @@ void menu_new_cb (GtkWidget *widget, void *data);
 void menu_computer_white_cb (GtkWidget *widget, void *data);
 void menu_computer_black_cb (GtkWidget *widget, void *data);
 void menu_two_players_cb (GtkWidget *widget, void *data);
-void menu_two_machines_cb (GtkWidget *widget, void *data);
 void menu_analyse_mode_cb (GtkWidget *widget, void *data);
 void level_cb (GtkWidget *widget, void *data);
 void menu_prefs_cb (GtkWidget *widget, void *data);
