@@ -65,8 +65,9 @@ static int promotion_dialog()
   GtkWidget *dialog;
   GtkWidget *label;
 
-  label = gtk_label_new ("Promotion into which piece?");
-  dialog = gnome_dialog_new ("Promotion","Queen","Rook","Bishop","Knight", NULL);
+  label = gtk_label_new (_("Promotion into which piece?"));
+  dialog = gnome_dialog_new (_("Promotion"),_("Queen"),_("Rook"),_("Bishop"),
+                             _("Knight"), NULL);
   gnome_dialog_set_default(GNOME_DIALOG (dialog),0);
   gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (dialog)->vbox), label, TRUE, TRUE, 0);
   gtk_widget_show (label);
