@@ -243,20 +243,19 @@ void gnomechess_movelist_clear_from(MoveList *movelist, unsigned int plynum) {
 	int i, adjust = 0;
 	move *mv;
 
-	if ((plynum % 2) == 0) {
-		mv = gtk_clist_get_row_data(GTK_CLIST(movelist->clist), (plynum/2)-1);
-		gtk_clist_set_text (GTK_CLIST(movelist->clist), (plynum/2)-1, 2, "");
+	if ((plynum % 2) == 1) {
+		mv = gtk_clist_get_row_data(GTK_CLIST(movelist->clist), (plynum/2));
+		gtk_clist_set_text (GTK_CLIST(movelist->clist), (plynum/2), 2, "");
 		free(mv->p[1]);
 		mv->p[1] = NULL;
-		plynum++;
-		adjust = 1;
 	}
+	plynum += 1;
+
 	for (i=plynum;i<=movelist->length;i+=2) {
 		gtk_clist_remove(GTK_CLIST(movelist->clist), plynum/2);
 	}
-	if (adjust) plynum-=2; else plynum--;
-	movelist->length = plynum;
-	gnomechess_movelist_movetoply(movelist, plynum);
+	movelist->length = plynum-1;
+	movelist->ply = plynum-1;
 }
 
 void gnomechess_movelist_clear_initial(MoveList *movelist, gint ply, position *pos)  {
