@@ -28,6 +28,7 @@
 #include <fcntl.h>
 
 #include "makros.h"
+#include "debug.h"
 #include "position.h"
 #include "pro.h"
 #include "movlist.h"
@@ -91,8 +92,8 @@ static struct
   { "BlackTitle", PGN_BLACK_TITLE },
   { "WhiteELO", PGN_WHITE_ELO },
   { "BlackELO", PGN_BLACK_ELO },
-  { "ELOWhite", PGN_WHITE_ELO }, // some broken programs use this
-  { "ELOBlack", PGN_BLACK_ELO }, // and this
+  { "ELOWhite", PGN_WHITE_ELO }, 	/* some broken programs use this
+  { "ELOBlack", PGN_BLACK_ELO },	and this */
   { "Remark", PGN_REMARK },
   { "ECO", PGN_ECO },
   { "NIC", PGN_NIC },
@@ -185,7 +186,6 @@ void pgn_test(void)
 
   for(i=0;i<n-1;i++)
     {
-      printf("Game %d\n",i+1);
       fseek(file,(long)game->data,SEEK_SET);
       txt_load_from_fp(file,(long)game->next->data - (long)game->data, TRUE);
       game = game->next;
@@ -241,7 +241,6 @@ void pgn_open(const char *fname)
     {
       struct pgn_tag tag;
       
-      printf("%ld\n",(long)g_list_nth_data(game_list,i));
       g_scanner_sync_file_offset_extern(s,(long)g_list_nth_data(game_list,i));
       pgn_header_load(s, &tag);
       pgn_clist_add(clist,tag);
@@ -267,7 +266,7 @@ static void  pgn_clist_add(GtkWidget * clist ,struct pgn_tag tag)
   char    *text[3] = { "", "","" };
   gint row;
 
-  printf("%s %s %s\n",tag.white,tag.black,tag.result);
+  debug_print(DEBUG_NORMAL,"%s %s %s\n",tag.white,tag.black,tag.result);
 
   row=gtk_clist_append (GTK_CLIST(clist), text);
   gtk_clist_set_text (GTK_CLIST(clist), row , 0, tag.white);
@@ -299,12 +298,8 @@ static GList * pgn_index(const char *fname)
 	{
 	  i++;
 
-	  if ( !(i % 1000)) printf("%d\n",i);
-
-	  // for now use g_list_prepend(), because it is much faster
-          // than g_list_append() ( O(1) vs. O(n) );
-
-	  // if (p != buf) printf("offset %d\n",p-buf);
+	  /* for now use g_list_prepend(), because it is much faster 
+		than g_list_append(), ( O(1) vs. O(n) ) */
 	  game_list = g_list_prepend(game_list,(void *) (tell + (p-buf)));
 	}
     }
@@ -320,7 +315,6 @@ static int txt_load_from_fp(FILE *fp, int len, int test)
   int ret;
 
   char *buf = malloc(len);
-  // printf("%d %d\n",len,test);
 
   fread(buf,len,1,fp);
   ret = txt_load(buf,len,test);
@@ -366,7 +360,7 @@ static void pgntag(GTokenValue value1, GTokenValue value2, struct pgn_tag *tag)
 	      tag->result = g_strdup(value2.v_string);
 	      break;
 	    default:
-	      // printf("unused Tag");
+	      debug_print(DEBUG_NORMAL, "Unused PGN tag found: %s.\n",value2.v_string);
 	    }
 }
 
@@ -407,7 +401,7 @@ static int txt_load(char *newbuf, int len, int test)
       GTokenValue value1,value2;
       GTokenType token2;
       GTokenType token =g_scanner_get_next_token(s);
-      //      printf("%d ",token);
+      debug_print(DEBUG_VERBOSE, "Token: %d ",token);
 
       if (token == G_TOKEN_EOF) break;
 
@@ -422,20 +416,17 @@ static int txt_load(char *newbuf, int len, int test)
 	    {
 	      g_scanner_get_next_token(s);
 	      value2 = g_scanner_cur_value(s);
-	      //	      printf (" \"%s\"]\n",value2.v_string);
 	      pgntag(value1,value2,tag);
 	    }
 	  else
 	    {
-	      printf ("Unknown Tag [%s", value1.v_string);
 	      g_scanner_get_next_token(s);
 	      value2 = g_scanner_cur_value(s);
-	      printf (" \"%s\"]\n",value2.v_string);
 	    }
 	  token2 =g_scanner_get_next_token(s);
 	  if (token2 != G_TOKEN_RIGHT_BRACE)
 	    {
-	      printf("parse error\n");
+	      debug_print(DEBUG_NONE, "Parse error!\n");
 	      ret = FALSE;
 	      goto finish;
 	    }
@@ -443,36 +434,29 @@ static int txt_load(char *newbuf, int len, int test)
 	case  G_TOKEN_RIGHT_BRACE:
 	case  G_TOKEN_SYMBOL:  
 	case  G_TOKEN_STRING:
-	  puts("parse error");
+	  debug_print(DEBUG_NONE,"Parse error!\n");
 	  break;
 	case  G_TOKEN_FLOAT:
-	  // puts("float");
 	  break;
 	case  G_TOKEN_IDENTIFIER:
-	  // puts("identifier");
 	  value1 = g_scanner_cur_value(s);
-	  //	  puts(value1.v_string);
 	  if (  '0' <=  *value1.v_string &&  *value1.v_string <= '9')
 	    break;
 	  txt_reg_move(value1.v_string, test);
-	  // g_free(value1.v_string);
 	  break;
-	case G_TOKEN_LEFT_CURLY: // comments are ignored for now
+	case G_TOKEN_LEFT_CURLY: /* comments are ignored for now */
 	  {
 	    do 
 	      {
 		token2 =g_scanner_get_next_token(s);
-		//    printf("CURLY: %d\n",token2);
 		if (token2 ==  G_TOKEN_IDENTIFIER) 
 		  {
-		    //   puts("identifier");
 		    value1 = g_scanner_cur_value(s);
-		    // puts(value1.v_string);
 		  }
 		else 
 		  if (token2 ==  G_TOKEN_EOF) 
 		    { 
-		      printf("EOF in comment!");
+		      debug_print(DEBUG_NONE, "EOF in comment!\n");
 		      ret = FALSE;
 		      goto finish;
 		    }
@@ -480,17 +464,17 @@ static int txt_load(char *newbuf, int len, int test)
 	    while(token2 != G_TOKEN_RIGHT_CURLY);
 	    break;
 	  }
-	case G_TOKEN_LEFT_PAREN: // RAVs are ignored for now
+	case G_TOKEN_LEFT_PAREN: /* RAVs are ignored for now */
 	  { 
 	    int nest=1;
-	    // printf("nest %d\n",nest);
+	    debug_print(DEBUG_VERBOSE, "Nest %d\n",nest);
 	    while(1) 
 	      {
 		token2 =g_scanner_get_next_token(s);
-		// printf("token: %d\n",token2);
+		debug_print(DEBUG_VERBOSE, "Token: %d\n",token2);
 		if (token2 == G_TOKEN_EOF)
 		  {
-		    printf("EOF in RAV!");
+		    debug_print(DEBUG_NONE,"EOF in RAV!\n");
 		    ret = FALSE;
 		    goto finish;
 		  }
@@ -498,13 +482,13 @@ static int txt_load(char *newbuf, int len, int test)
 		if (token2 == G_TOKEN_LEFT_PAREN) 
 		  {
 		    nest++;
-		    //  printf("nest %d\n",nest);
+	    	debug_print(DEBUG_VERBOSE, "Nest %d\n",nest);
 		  }
 		else
 		if (token2 == G_TOKEN_RIGHT_PAREN) 
 		  {
 		    nest--;
-		    // printf("unnest %d\n",nest);
+	    	debug_print(DEBUG_VERBOSE, "Unnest %d\n",nest);
 		    if (!nest) break;
 		  }
 
@@ -512,7 +496,7 @@ static int txt_load(char *newbuf, int len, int test)
 	  }
 	  break;
 	default:
-	  printf("unknown %d\n",token);
+	  debug_print(DEBUG_NONE, "Unknown token: %d\n",token);
 	  ret = FALSE;
 	  goto finish;
 	}
@@ -533,7 +517,7 @@ static void pgn_header_load(GScanner *s, struct pgn_tag * tp)
     {
       GTokenValue value1,value2;
       GTokenType token =g_scanner_get_next_token(s);
-//      printf("%d\n",token);
+	  debug_print(DEBUG_VERBOSE, "Token: %d\n",token);
 
 	if (token == G_TOKEN_EOF) break;
 
@@ -551,21 +535,16 @@ static void pgn_header_load(GScanner *s, struct pgn_tag * tp)
 	  pgntag(value1,value2,tp);
 	  break;
 	case  G_TOKEN_STRING:
-	  puts("string");
 	  break;
 	case  G_TOKEN_FLOAT:
-	  // puts("float");
 	  break;
 	case  G_TOKEN_IDENTIFIER:
-	  // puts("identifier");
 	  value1 = g_scanner_cur_value(s);
-	  // puts(value1.v_string);
-	  // txt_reg_move(value1.v_string);
 	  goto finish;
 	  break;
 	  
 	default:
-	  printf("unknown %d\n",token);
+	  debug_print(DEBUG_NONE, "Unknown token: %d\n",token);
 	  return;
 	}
     }
@@ -685,11 +664,10 @@ static int txt_reg_move(char *str, int test)
 	  return txt_reg_move_found(aq,test);
       }
   }
-  printf("not found: %s\n",str);
   return FALSE;
 }
 
-static char *titles[] = { "White","Black","Result"};
+static char *titles[] = { N_("White"), N_("Black"), N_("Result")};
 
 static  GtkWidget  * pgn_clist_new(GList *game_list)
 {
@@ -755,7 +733,6 @@ select_game(GtkWidget * widget,int row,int column,GdkEventButton * event,GList *
 {
 	FILE *fp;
 	gchar *text;
-	printf("select game");
 
 	fp = fopen(filename,"r");
 	if (fp) {
