@@ -19,9 +19,11 @@
 #ifndef _PRO_H
 #define _PRO_H
 
-WORD legal_move(BYTE **,WORD *,WORD *);
+#include <glib.h>
+
+gshort legal_move(gchar **,gshort *,gshort *);
 void notation_update(int piece, int from, int to);
-WORD reg_zug(WORD von,WORD nach);
-int  move_generator(BYTE **,WORD *,WORD *);
+gshort reg_zug(gshort von,gshort nach);
+int  move_generator(gchar **,gshort *,gshort *);
 
 #endif /* _PRO_H */
