@@ -45,7 +45,7 @@ struct defaultserv dserv[] =
      {0,0,0,0}
 };
 
-// Prototypes for functions used internally
+/* Prototypes for functions used internally */
 void add_defaults(void);
 char *read_next_server_entry(char *my_cfg, struct serverentry *serv);
 void load_serverentrys(void);
@@ -364,7 +364,7 @@ void handle_comment(GtkWidget *igad)
 
 void open_server_list(GtkWidget *widd, void *data)
 {
-   static gchar *titles[] = {"Server", "Port", "Username", "Password", "Comment"};
+   static gchar *titles[] = {_("Server"), _("Port"), _("Username"), _("Password"), _("Comment")};
    GtkWidget *vbox, *box, *wid;
 
    if(slwin)
@@ -374,7 +374,7 @@ void open_server_list(GtkWidget *widd, void *data)
    }
 
    slwin = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-   gtk_window_set_title(GTK_WINDOW(slwin), "Gnome-Chess: Server List");
+   gtk_window_set_title(GTK_WINDOW(slwin), _("Gnome-Chess: Server List"));
    gtk_signal_connect(GTK_OBJECT(slwin), "delete_event",
                        GTK_SIGNAL_FUNC(close_server_list), 0);
    gtk_window_set_policy(GTK_WINDOW(slwin), TRUE, TRUE, FALSE);
@@ -397,11 +397,11 @@ void open_server_list(GtkWidget *widd, void *data)
    gtk_box_pack_start(GTK_BOX(vbox), box, FALSE, TRUE, 5);
    gtk_widget_show(box);
 
-   gtkutil_label_new("Server Name:", box);
+   gtkutil_label_new(_("Server Name:"), box);
 
    entry_server = gtkutil_entry_new(99, box, handle_server, 0);
 
-   gtkutil_label_new("Port:", box);
+   gtkutil_label_new(_("Port:"), box);
 
    entry_port = gtkutil_entry_new(14, box, handle_port, 0);
    gtk_widget_set_usize(entry_port, 80, -1);
@@ -410,16 +410,16 @@ void open_server_list(GtkWidget *widd, void *data)
    gtk_box_pack_start(GTK_BOX(vbox), box, FALSE, TRUE, 5);
    gtk_widget_show(box);
 
-   gtkutil_label_new("User Name:", box);
+   gtkutil_label_new(_("User Name:"), box);
 
    entry_user = gtkutil_entry_new(85, box, handle_user, 0);
 
-   gtkutil_label_new("Password:", box);
+   gtkutil_label_new(_("Password:"), box);
 
    entry_password = gtkutil_entry_new(85, box, handle_password, 0);
    gtk_widget_set_usize(entry_password, 80, -1);
 
-   gtkutil_label_new("Comment:", box);
+   gtkutil_label_new(_("Comment:"), box);
 
    entry_comment = gtkutil_entry_new(99, box, handle_comment, 0);
    gtk_widget_set_usize(entry_comment, 160, -1);
@@ -433,14 +433,14 @@ void open_server_list(GtkWidget *widd, void *data)
    gtk_box_pack_start(GTK_BOX(vbox), box, FALSE, TRUE, 2);
    gtk_widget_show(box);
 
-   gtkutil_button_new("Connect", 0, 0, connect_clicked, NULL, box);
-   gtkutil_stock_button(slwin, GNOME_STOCK_PIXMAP_NEW, "New Server",
+   gtkutil_button_new(_("Connect"), 0, 0, connect_clicked, NULL, box);
+   gtkutil_stock_button(slwin, GNOME_STOCK_PIXMAP_NEW, _("New Server"),
 			  new_server_clicked, NULL, box);
-   gtkutil_stock_button(slwin, GNOME_STOCK_PIXMAP_CLOSE, "Delete Server",
+   gtkutil_stock_button(slwin, GNOME_STOCK_PIXMAP_CLOSE, _("Delete Server"),
 			  delete_server_clicked, NULL, box);
-   gtkutil_stock_button(slwin, GNOME_STOCK_PIXMAP_UP, "Move Up",
+   gtkutil_stock_button(slwin, GNOME_STOCK_PIXMAP_UP, _("Move Up"),
 			  move_up_clicked, NULL, box);
-   gtkutil_stock_button(slwin, GNOME_STOCK_PIXMAP_DOWN, "Move Dn",
+   gtkutil_stock_button(slwin, GNOME_STOCK_PIXMAP_DOWN, _("Move Dn"),
 			  move_dn_clicked, NULL, box);
 
    load_serverentrys();
